@@ -1,11 +1,13 @@
-import os
+import pkg_resources
 
 from cqlengine.columns import *
 from cqlengine.functions import *
 from cqlengine.models import Model
 from cqlengine.query import BatchQuery
 
-__cqlengine_version_path__ = os.path.realpath(__file__ + '/../VERSION')
+
+__cqlengine_version_path__ = pkg_resources.resource_filename('cqlengine',
+                                                             'VERSION')
 __version__ = open(__cqlengine_version_path__, 'r').readline().strip()
 
 # compaction
