@@ -5,6 +5,7 @@ from datetime import date
 import re
 from uuid import uuid1, uuid4
 from cql.query import cql_quote
+from cql.cqltypes import DateType
 
 from cqlengine.exceptions import ValidationError
 
@@ -209,7 +210,11 @@ class Bytes(Column):
     def to_database(self, value):
         val = super(Bytes, self).to_database(value)
         if val is None: return
-        return val.encode('hex')
+        return '0x' + val.encode('hex')
+
+    def to_python(self, value):
+        #return value[2:].decode('hex')
+        return value
 
 
 class Ascii(Column):
@@ -326,7 +331,10 @@ class DateTime(Column):
             return value
         elif isinstance(value, date):
             return datetime(*(value.timetuple()[:6]))
-        return datetime.utcfromtimestamp(value)
+        try:
+            return datetime.utcfromtimestamp(value)
+        except TypeError:
+            return datetime.utcfromtimestamp(DateType.deserialize(value))
 
     def to_database(self, value):
         value = super(DateTime, self).to_database(value)
@@ -345,15 +353,16 @@ class DateTime(Column):
 class Date(Column):
     db_type = 'timestamp'
 
-
     def to_python(self, value):
         if value is None: return
         if isinstance(value, datetime):
             return value.date()
         elif isinstance(value, date):
             return value
-
-        return datetime.utcfromtimestamp(value).date()
+        try:
+            return datetime.utcfromtimestamp(value).date()
+        except TypeError:
+            return datetime.utcfromtimestamp(DateType.deserialize(value)).date()
 
     def to_database(self, value):
         value = super(Date, self).to_database(value)
@@ -442,11 +451,17 @@ class Boolean(Column):
         def __str__(self):
             return 'true' if self.value else 'false'
 
-    def to_python(self, value):
+    def validate(self, value):
+        """ Always returns a Python boolean. """
+        if isinstance(value, self.Quoter):
+            value = value.value
         return bool(value)
 
+    def to_python(self, value):
+        return self.validate(value)
+
     def to_database(self, value):
-        return self.Quoter(bool(value))
+        return self.Quoter(self.validate(value))
 
 
 class Float(Column):
@@ -522,7 +537,7 @@ class BaseContainerColumn(Column):
         Returns a column definition for CQL table definition
         """
         db_type = self.db_type.format(self.value_type.db_type)
-        return '{} {}'.format(self.db_field_name, db_type)
+        return '{} {}'.format(self.cql, db_type)
 
     def get_update_statement(self, val, prev, ctx):
         """
@@ -763,6 +778,12 @@ class Map(BaseContainerColumn):
             cq = cql_quote
             return '{' + ', '.join([cq(k) + ':' + cq(v) for k,v in self.value.items()]) + '}'
 
+        def get(self, key):
+            return self.value.get(key)
+
+        def keys(self):
+            return self.value.keys()
+
     def __init__(self, key_type, value_type, default=dict, **kwargs):
         """
         :param key_type: a column class indicating the types of the key
@@ -792,7 +813,7 @@ class Map(BaseContainerColumn):
             self.key_type.db_type,
             self.value_type.db_type
         )
-        return '{} {}'.format(self.db_field_name, db_type)
+        return '{} {}'.format(self.cql, db_type)
 
     def validate(self, value):
         val = super(Map, self).validate(value)
