@@ -385,7 +385,7 @@ class AbstractQuerySet(object):
                 if len(partition_columns) != len(val.value):
                     raise QueryException(
                         'Token() received {} arguments but model has {} partition keys'.format(
-                            len(partition_columns), len(val.value)))
+                            len(val.value), len(partition_columns)))
                 val.set_columns(partition_columns)
 
             #get query operator, or use equals if not supplied
@@ -663,24 +663,37 @@ class ModelQuerySet(AbstractQuerySet):
         nulled_columns = set()
         us = UpdateStatement(self.column_family_name, where=self._where, ttl=self._ttl, timestamp=self._timestamp)
         for name, val in values.items():
-            col = self.model._columns.get(name)
+            col_name, col_op = self._parse_filter_arg(name)
+            col = self.model._columns.get(col_name)
             # check for nonexistant columns
             if col is None:
-                raise ValidationError("{}.{} has no column named: {}".format(self.__module__, self.model.__name__, name))
+                raise ValidationError("{}.{} has no column named: {}".format(self.__module__, self.model.__name__, col_name))
             # check for primary key update attempts
             if col.is_primary_key:
-                raise ValidationError("Cannot apply update to primary key '{}' for {}.{}".format(name, self.__module__, self.model.__name__))
+                raise ValidationError("Cannot apply update to primary key '{}' for {}.{}".format(col_name, self.__module__, self.model.__name__))
 
             val = col.validate(val)
             if val is None:
-                nulled_columns.add(name)
+                nulled_columns.add(col_name)
                 continue
+
             # add the update statements
             if isinstance(col, Counter):
                 # TODO: implement counter updates
                 raise NotImplementedError
+            elif isinstance(col, (List, Set, Map)):
+                if isinstance(col, List):
+                    klass = ListUpdateClause
+                elif isinstance(col, Set):
+                    klass = SetUpdateClause
+                elif isinstance(col, Map):
+                    klass = MapUpdateClause
+                else:
+                    raise RuntimeError
+                us.add_assignment_clause(klass(col_name, col.to_database(val), operation=col_op))
             else:
-                us.add_assignment_clause(AssignmentClause(name, col.to_database(val)))
+                us.add_assignment_clause(AssignmentClause(
+                    col_name, col.to_database(val)))
 
         if us.assignments:
             self._execute(us)
@@ -784,7 +797,8 @@ class DMLQuery(object):
                     else: raise RuntimeError
 
                     # do the stuff
-                    clause = klass(col.db_field_name, val, val_mgr.previous_value, column=col)
+                    clause = klass(col.db_field_name, val,
+                            previous=val_mgr.previous_value, column=col)
                     if clause.get_context_size() > 0:
                         statement.add_assignment_clause(clause)
                 else:
